#!/usr/bin/env python
#example

# python ReadSCFileNominal.py NominalGain/ physics_20061108_220357.4

from I3Tray import *
from os.path import expandvars

indir = "/disk3/data/IceCube/RealData/2007/level0/0801/"
runname = "PFFilt_PhysicsTrig_PhysicsFiltering_Run00108981_Level0_Part00000001"
ingcsfile   = "PFFilt_PhysicsTrig_PhysicsFiltering_Run00108981_Level0_GCD.i3.gz"
outdir = "/home/mase/work/I3/SIMULATION/V02EHE/build/tmp"

if len(sys.argv) > 1:
	indir = sys.argv[1]
	
if len(sys.argv) > 2:
	runname = sys.argv[2]
		
if len(sys.argv) > 3:
	ingcsfile = sys.argv[3]

if len(sys.argv) > 4:
	outdir = sys.argv[4]
		
inphysfile = indir + runname + ".i3.gz"
#ingcsfile = indir + ingcsfile
outfile = outdir + runname + ".root"
outcanvas1file = outdir + runname + "-canvas1.gif"
outcanvas2file = outdir + runname + "-canvas2.gif"

print ingcsfile
print inphysfile
#outfile 

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libdataio")
load("libpfclasses")
load("libDOMcalibrator")
load("libicepick")
load("libDomTools")
#load("libtriggerUtil-C++")
#our module
load("libportia")
load("libophelia")
load("librealtree-module")
#load("../../../Sim-V01-09-04-EHE/Linux-i386/lib/librealtree-module")

tray = I3Tray()

tray.AddService("I3ReaderServiceFactory","reader")(
    ("FilenameList", [ingcsfile, inphysfile]),
    ("SkipUnregistered", True)
    )

tray.AddModule("I3Muxer", "multiplex")

tray.AddModule("I3DOMLaunchCleaning","launchcleaning")(
	("InIceInput","InIceRawData"),
	("IceTopInput","IceTopRawData"),
	("InIceOutput","CleanInIceRawData"),
	("IceTopOutput","CleanIceTopRawData"),
	("FirstLaunchCleaning",True),
	("CleanedKeys",[OMKey(29,59),#Dead/problem list
			OMKey(29,60),
			OMKey(30,23),
			OMKey(30,60),
			OMKey(38,59),
			OMKey(39,22),
			OMKey(50,36),
			OMKey(74,9),
			OMKey(40,51),
			OMKey(40,52),
			OMKey(46,49),
			OMKey(46,50),
			OMKey(46,53),
			OMKey(46,54),
			OMKey(46,55),
			OMKey(46,56),
			OMKey(47,55),
			OMKey(47,56),
			OMKey(56,57),
			OMKey(56,58),
			OMKey(72,37),
			OMKey(72,38),
			OMKey(39,8), #Dark Noise mode only DOMS
			OMKey(50,58),
			OMKey(72,33),
			OMKey(72,34),
			OMKey(72,35),
			OMKey(72,36),
			OMKey(72,43),])
	)


tray.AddModule("I3DOMcalibrator","DOMcalib")(
	("InputRawDataName","CleanInIceRawData"),
	("CorrectPedestalDroop", False),
	("CalibrationMode", 1),
	)

tray.AddModule("I3Portia","pulse")(
  ("DataReadoutName",             "CleanInIceRawData"),
  ("ATWDPulseSeriesName",         "ATWDPulseSeries"),
  ("ATWDPortiaPulseName",         "ATWDPortiaPulse"),
  ("ATWDWaveformName",            "CalibratedATWD"),
#
  ("ATWDBaseLineOption",          "eheoptimized"),
  ("FADCBaseLineOption",          "eheoptimized"),
  #("ATWDBaseLineOption",          "iteration"),
  #("FADCBaseLineOption",          "iteration"),
  #("ATWDBaseLineOption",          "zerobaseline"),
  #("FADCBaseLineOption",          "zerobaseline"),
  #("ATWDBaseLineOption",          "first"),
  #("FADCBaseLineOption",          "first"),
#
  ("ATWDThresholdCharge",         0.0*I3Units.C),
  ("ATWDLEThresholdAmplitude",    0.5*I3Units.mV),

  ("UseFADC", True),
  ("FADCPulseSeriesName",         "FADCPulseSeries"),
  ("FADCPortiaPulseName",         "FADCPortiaPulse"),
  ("FADCWaveformName",            "CalibratedFADC"),
  ("FADCThresholdCharge",         0.0*I3Units.C),
  ("FADCLEThresholdAmplitude",    0.5*I3Units.mV),
  ("MakeBestPulseSeries",         False),
  ("BestPortiaPulseName",         "BestPortiaPulse"),
  #("PMTGain",                     1.0e7)
  #("PMTGain",                      5.0e6)
)

tray.AddModule("I3EHEFirstGuess", "reco")(
  ("MinimumNumberPulseDom",  8),
  ("OutputFirstguessName",   "OpheliaFirstGuess"),
  ("InputPulseName1",        "ATWDPortiaPulse"),
  ("InputPulseName2",        "FADCPortiaPulse"),
  ("InputLaunchName",        "CleanInIceRawData"),
  ("ChargeOption",           0),
  ("LCOption",               True)
)

tray.AddModule("I3RealTreeModule","real")(
  ("outTreeName",            "RealTree"),
  ("outFileName",            outfile),  
  ("inDOMLaunchName",        "CleanInIceRawData"),
  ("UseIceTopPulse",         True),
  ("inTopDOMLaunchName",     "CleanIceTopRawData"),
  ("doPulseTree",            True),
  ("inAtwdPortiaName",       "ATWDPortiaPulse"),
  ("inFadcPortiaName",       "FADCPortiaPulse"),
  ("doWaveformDraw",         False),
  ("DrawOption",             2),
  ("inAtwdWaveformToDraw",   "CalibratedATWD"),
  ("inFadcWaveformToDraw",   "CalibratedFADC"),
  ("outputCanvas1Name",      outcanvas1file),
  ("outputCanvas2Name",      outcanvas2file),   
  ("doFirstguessTree",       True),
  ("inFirstguessName",       "OpheliaFirstGuess")
)

tray.AddModule("TrashCan", "bye")

tray.Execute()
tray.Finish()
